export INPUT_PATH=""
export OUTPUT_PATH=""

mkdir -p ${OUTPUT_PATH}

find ${INPUT_PATH} -type f -name "*.pset" > pset_file.list
touch pset_mp1.list
touch final_mp.list
touch final_pset_list.list
touch final_mp_without_pset.list
touch script_generation_error.list
touch script_generation_success.list

for pset_file in `cat pset_file.list`; 
do 
	export pset_file1=${pset_file}
	export mp_file_from_pset=$(cat ${pset_file} |head -1 |awk -v FS="/" '{ print $NF }')
	
	echo "${pset_file1}|${mp_file_from_pset}" >> pset_mp1.list 
	
done;

#removing plan psets from pset_mp_list
grep -vE '.plan' pset_mp1.list	> pset_mp.list


find ${INPUT_PATH} -type f -name "*.mp" > mp_file.list

for mp_file in `cat mp_file.list`; 
do 
	export mp_file1=${mp_file}
	export mp_file2=$(echo ${mp_file} |awk -v FS="/" '{ print $NF }')
	
	echo "${mp_file1}|${mp_file2}" >> final_mp.list 
	
done;


for mp in `cat final_mp.list`;
do
    export mp1=$(echo ${mp} |cut -f 2 -d '|')
	export return_value=$(cat pset_mp.list |grep ${mp1} |cut -f 1 -d '|' | wc -l)
      if [ $return_value -ne 0 ]
      then
          cat pset_mp.list |grep $mp1 |cut -f 1 -d '|' >> final_pset_list.list
      else
          echo "${mp}" | cut -f 1 -d '|' >> final_mp_without_pset.list
      fi
done;	

export scriptFailureMessage="Command Failed:"
export total_pset_count=$(cat final_pset_list.list | wc -l)
export pset_fail_count=0
for pset_file in `cat final_pset_list.list`; 
do 
	echo "##### Generating Script for file : ${pset_file} "   
	
	export INPUT_FILE_DIR=$(dirname "${pset_file}")
	export RELATIVE_PATH=$(echo $(echo ${INPUT_FILE_DIR#${INPUT_PATH}}/) | sed 's/\/pset\//\/run\//')
	
	echo "RELATIVE_PATH = "${RELATIVE_PATH}
	export ksh_file_name="$(echo "$(basename ${pset_file})" | cut -f 1 -d '.').ksh"
	
	mkdir -p ${OUTPUT_PATH}/${RELATIVE_PATH}/
	air sandbox run ${pset_file} -script-only > ${OUTPUT_PATH}/${RELATIVE_PATH}/${ksh_file_name} 2>&1
	export return_value=$(cat ${OUTPUT_PATH}/${RELATIVE_PATH}/${ksh_file_name} | grep "${scriptFailureMessage}" | wc -l)
	if [ "$return_value" -ne 0 ]; then
        export error_msg=$(cat ${OUTPUT_PATH}/${RELATIVE_PATH}/${ksh_file_name}| grep -e "does not have a value." -e "not found." -e "No such file or directory.")
	    echo "${pset_file}|${error_msg}" >> script_generation_error.list
	    echo "---------------------------------------------------------------------------" >> script_generation_error.list
	    pset_fail_count=$(($pset_fail_count+1)) 
    else
        echo "Script generation successfull for : ${pset_file}"
        echo "${pset_file}" >> script_generation_success.list
fi
done;


export total_mp_count=$(cat final_mp_without_pset.list | wc -l)
export mp_fail_count=0
for mp_file in `cat final_mp_without_pset.list`; 
do 
	echo "##### Generating Script for file : ${mp_file} "   
	
	export INPUT_FILE_DIR=$(dirname "${mp_file}")	
	export RELATIVE_PATH=$(echo $(echo ${INPUT_FILE_DIR#${INPUT_PATH}}/) | sed 's/\/mp\//\/run\//')
	
	echo "RELATIVE_PATH = "${RELATIVE_PATH}
	export ksh_file_name="$(echo "$(basename ${mp_file})" | cut -f 1 -d '.').ksh"
	
	mkdir -p ${OUTPUT_PATH}/${RELATIVE_PATH}/
	air sandbox run ${mp_file} -script-only > ${OUTPUT_PATH}/${RELATIVE_PATH}/${ksh_file_name} 2>&1
	export return_value=$(cat ${OUTPUT_PATH}/${RELATIVE_PATH}/${ksh_file_name} | grep "${scriptFailureMessage}" | wc -l)
	if [ "$return_value" -ne 0 ]; then
        export error_msg=$(cat ${OUTPUT_PATH}/${RELATIVE_PATH}/${ksh_file_name} | grep -e "does not have a value." -e "not found." -e "No such file or directory.")
	    echo "${mp_file}|${error_msg}" >> script_generation_error.list
	    echo "---------------------------------------------------------------------------" >> script_generation_error.list
	    mp_fail_count=$(($mp_fail_count+1)) 
    else
      echo "Script generation successfull for : ${mp_file}"
      echo "${mp_file}" >> script_generation_success.list
    fi
	  
	  
done;


export total_input_files=$(($total_pset_count+$total_mp_count))
export total_fail_count=$(($pset_fail_count+$mp_fail_count)) 
export total_success_count=$(($total_input_files-$total_fail_count)) 
echo "Total input files provided for ksh generation : ${total_input_files}"
echo "Total success : ${total_success_count}"
echo "Total failure : ${total_fail_count}"
rm pset_mp1.list
rm pset_mp.list
#rm final_mp.list
#rm final_pset_list.list
#rm final_mp_without_pset.list
#rm script_generation_error.list
#rm script_generation_success.list